pyautomailer: a fully customizable automatic email client service.
##################################################################

pyautomailer is a Python module (with command line tool to use it from terminal) that allows you to send massive custom email. 
It can be used with massive SMTP sending service or with standard mailbox after setting sending limit.

.. contents::

.. section-numbering::

Main features
=============

* HTML dynamic email Subject and Body

Installation
============

Windows
-------

On Windows, pyautomailer can be installed via PyPi (recommended):

.. code-block:: python

	python setup.py install